@@ -6,11 +6,12 @@ use compact::compound::Operations;
 use compact::primitive::{Offset, OffsetSize, StringID};
 
 table_define! {
+    #[doc = "An index."]
     pub Index {
-        count   (u16         ),
-        offSize (OffsetSize  ),
-        offset  (Vec<Offset> ),
-        data    (Vec<Vec<u8>>),
+        count       (u16         ),
+        offset_size (OffsetSize  ),
+        offsets     (Vec<Offset> ),
+        data        (Vec<Vec<u8>>),
     }
 }
 
@@ -20,40 +21,39 @@ impl Value for Index {
         if count == 0 {
             return Ok(Index::default());
         }
-        let offSize = try!(band.take::<OffsetSize>());
-        let mut offset = Vec::with_capacity(count as usize + 1);
+        let offset_size = try!(band.take::<OffsetSize>());
+        let mut offsets = Vec::with_capacity(count as usize + 1);
         for i in 0..(count as usize + 1) {
-            let value = try!(Offset::read(band, offSize));
-            if i == 0 && value != Offset(1) || i > 0 && value <= offset[i - 1] {
+            let offset = try!(Offset::read(band, offset_size));
+            if i == 0 && offset != Offset(1) || i > 0 && offset <= offsets[i - 1] {
                 raise!("found a malformed index");
             }
-            offset.push(value);
+            offsets.push(offset);
         }
         let mut data = Vec::with_capacity(count as usize);
         for i in 0..(count as usize) {
-            let size = (offset[i + 1].as_u32() - offset[i].as_u32()) as usize;
+            let size = (offsets[i + 1].as_u32() - offsets[i].as_u32()) as usize;
             data.push(try!(ValueExt::read(band, size)));
         }
-        Ok(Index { count: count, offSize: offSize, offset: offset, data: data })
+        Ok(Index { count: count, offset_size: offset_size, offsets: offsets, data: data })
     }
 }
 
 deref! { Index::data => [Vec<u8>] }
 
 macro_rules! index {
-    ($(#[$attribute:meta])* $structure:ident) => (
-        index_define! { $(#[$attribute])* pub $structure {} }
+    ($(#[$attribute:meta])* pub $structure:ident) => (
+        index_define! { $(#[$attribute])* pub $structure }
         index_implement! { $structure }
     );
 }
 
 macro_rules! index_define {
-    ($(#[$attribute:meta])* pub $structure:ident { $($field:ident: $kind:ty,)* }) => (
+    ($(#[$attribute:meta])* pub $structure:ident) => (
         $(#[$attribute])*
         #[derive(Clone, Debug, Default, Eq, PartialEq)]
         pub struct $structure {
             index: ::compact::compound::Index,
-            $($field: $kind,)*
         }
 
         deref! { $structure::index => ::compact::compound::Index }
@@ -72,14 +72,29 @@ macro_rules! index_implement {
 }
 
 index_define! {
-    pub Charstrings {
-    }
+    #[doc = "A charstrings index."]
+    pub Charstrings
 }
 
-index!(TopDictionaries);
-index!(Names);
-index!(Strings);
-index!(Subroutines);
+index! {
+    #[doc = "A top-dictionaries index."]
+    pub TopDictionaries
+}
+
+index! {
+    #[doc = "A names index."]
+    pub Names
+}
+
+index! {
+    #[doc = "A strings index."]
+    pub Strings
+}
+
+index! {
+    #[doc = "A subroutines index."]
+    pub Subroutines
+}
 
 impl ValueExt<i32> for Charstrings {
     fn read<T: Band>(band: &mut T, format: i32) -> Result<Self> {
@@ -91,6 +106,7 @@ impl ValueExt<i32> for Charstrings {
 }
 
 impl TopDictionaries {
+    #[doc(hidden)]
     pub fn into_vec(self) -> Result<Vec<Operations>> {
         let TopDictionaries { index: Index { data, .. } } = self;
         let mut vector = Vec::with_capacity(data.len());
@@ -102,6 +118,7 @@ impl TopDictionaries {
 }
 
 impl Names {
+    #[doc(hidden)]
     pub fn into_vec(self) -> Result<Vec<String>> {
         let Names { index: Index { data, .. } } = self;
         let mut vector = Vec::with_capacity(data.len());
@@ -116,6 +133,7 @@ impl Names {
 }
 
 impl Strings {
+    /// Return the string corresponding to a string identifier.
     pub fn get(&self, sid: StringID) -> Option<String> {
         match sid as usize {
             i if i < NUMBER_OF_STANDARD_STRINGS => {
